@@ -316,7 +316,7 @@ impl<'a, I: Tokens> Parser<I> {
                 tok!("null")
                 | tok!("true")
                 | tok!("false")
-                | Token::Num(..)
+                | Token::Num { .. }
                 | Token::BigInt { .. }
                 | Token::Str { .. } => {
                     return Ok(Box::new(Expr::Lit(self.parse_lit()?)));
@@ -1827,10 +1827,11 @@ impl<'a, I: Tokens> Parser<I> {
                 }),
                 _ => unreachable!(),
             },
-            Token::Num(..) => match bump!(self) {
-                Token::Num(value) => Lit::Num(Number {
+            Token::Num { .. } => match bump!(self) {
+                Token::Num { value, raw } => Lit::Num(Number {
                     span: span!(self, start),
                     value,
+                    raw: Some(raw),
                 }),
                 _ => unreachable!(),
             },
