@@ -55,13 +55,10 @@ impl<'a, I: Tokens> Parser<I> {
         let str_start = cur_pos!(self);
         if let Ok(&Token::Str { .. }) = cur!(self, false) {
             let src = match bump!(self) {
-                Token::Str { value, has_escape } => Str {
+                Token::Str { value, raw, .. } => Str {
                     span: span!(self, str_start),
                     value,
-                    has_escape,
-                    kind: StrKind::Normal {
-                        contains_quote: true,
-                    },
+                    raw: Some(raw),
                 },
                 _ => unreachable!(),
             };
@@ -147,13 +144,10 @@ impl<'a, I: Tokens> Parser<I> {
             let str_start = cur_pos!(self);
             let src = match *cur!(self, true)? {
                 Token::Str { .. } => match bump!(self) {
-                    Token::Str { value, has_escape } => Str {
-                        value,
-                        has_escape,
+                    Token::Str { value, raw, .. } => Str {
                         span: span!(self, str_start),
-                        kind: StrKind::Normal {
-                            contains_quote: true,
-                        },
+                        value,
+                        raw: Some(raw),
                     },
                     _ => unreachable!(),
                 },
@@ -782,13 +776,10 @@ impl<'a, I: Tokens> Parser<I> {
         let str_start = cur_pos!(self);
         let src = match *cur!(self, true)? {
             Token::Str { .. } => match bump!(self) {
-                Token::Str { value, has_escape } => Str {
-                    value,
-                    has_escape,
+                Token::Str { value, raw, .. } => Str {
                     span: span!(self, str_start),
-                    kind: StrKind::Normal {
-                        contains_quote: true,
-                    },
+                    value,
+                    raw: Some(raw),
                 },
                 _ => unreachable!(),
             },
